.. _openapi:

Documentation of Thamos Python client
-------------------------------------

This documentation is automatically generated from sources.

.. openapi:: ../../../user-api/openapi/openapi.yaml
